MapConfigurationSource class final

A ConfigurationSource that produces a MapConfigurationProvider.

Register via ConfigurationBuilder.addMap:

builder.addMap({
  'database': {'host': 'localhost', 'port': 5432},
  'logging': {'level': 'info'},
});
Implemented types

Constructors

MapConfigurationSource({required Map<String, dynamic> map})
Creates a source from map.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() ConfigurationProvider
Creates the ConfigurationProvider managed by this source.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited