MemoryConfigurationSource class final

A ConfigurationSource that produces a MemoryConfigurationProvider.

Register via ConfigurationBuilder.addInMemory:

builder.addInMemory({'app:name': 'Orders'});
Implemented types

Constructors

MemoryConfigurationSource({Map<String, String?>? initialData})
Creates a source seeded with initialData.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
initialData Map<String, String?>
The initial key-value pairs.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() ConfigurationProvider
Creates the ConfigurationProvider managed by this source.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited